@@ -915,7 +915,8 @@ class ArtimonLocalHandler(BaseArtimon):
         self._asctime(record)
         self._engine(record, 'artimon')
         file_name = (
-            f"{self.path}{os.sep}{dt.now().strftime('%Y%m%d_%H:%M:%S:%f')}"
+            f"{self.path}{os.sep}{record.name.replace('.', '_')}_"
+            f"{dt.now().strftime('%Y%m%d_%H:%M:%S:%f')}"
         )
         with open(f"{file_name}.tmp", 'w') as file:
             file.write(self.parser(record)+'\n')
